@@ -39,8 +39,15 @@ class CeleryClient(object):
         rs_key = get_result_key(app_code=self.app_code, task_name=task_name, task_id=async_result.id)
         self.rds_client.set(rs_key, callback.json(), ex=self.default_expire_seconds)
 
-    # 异步请求
     def apply_async(self, task_name: str, task_params: Dict = None, callback: Callback = None, **kwargs):
+        """
+        异步请求
+        :param task_name: 任务名
+        :param task_params: 任务参数
+        :param callback: 回调对象
+        :param kwargs: 扩展参数
+        :return:
+        """
         LOGGER.info(f'[服务]异步调用 task={task_name}')
         try:
             _headers = dict()
@@ -57,8 +64,14 @@ class CeleryClient(object):
             LOGGER.error(f'处理异常: task_name={task_name}, kwargs={task_params}, callback={callback}, e={e}')
             raise e
 
-    # 同步请求
     def apply_sync(self, task_name: str, task_params: Dict = None, **kwargs):
+        """
+        同步请求
+        :param task_name: 任务名
+        :param task_params: 任务参数
+        :param kwargs: 扩展参数
+        :return:
+        """
         LOGGER.info(f'[服务]同步调用 task={task_name}')
         try:
             _headers = {'app_code': self.app_code}
@@ -68,7 +81,9 @@ class CeleryClient(object):
             _timeout = 60
             if kwargs and kwargs.get('timeout', None):
                 _timeout = float(kwargs.get('timeout'))
-            return async_result.get(timeout=_timeout)
+            rs = async_result.get(timeout=_timeout)
+            async_result.forget()
+            return rs
         except Exception as e:
             LOGGER.error(f'处理异常: task_name={task_name}, kwargs={task_params}, e={e}')
             raise e
